"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.OTPInput = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _boxDigit = require("../box-digit");
var _constants = require("../../common/constants");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const OTPInput = _ref => {
  let {
    onSubmit,
    pinCount = 4,
    boxSelectedStyle,
    boxStyle,
    digitStyle,
    boxContainerStyle
  } = _ref;
  const [code, setCode] = (0, _react.useState)((0, _constants.initCode)(pinCount));
  const [idxFocusing, setIdxFocusing] = (0, _react.useState)(0);
  const inputRef = (0, _react.useRef)();
  const handleOnPress = idx => {
    return () => {
      var _inputRef$current, _inputRef$current$foc;
      inputRef === null || inputRef === void 0 ? void 0 : (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : (_inputRef$current$foc = _inputRef$current.focus) === null || _inputRef$current$foc === void 0 ? void 0 : _inputRef$current$foc.call(_inputRef$current);
      setIdxFocusing(idx);
    };
  };

  // Handle box digit here
  const handleOnKeyPress = _ref2 => {
    let {
      nativeEvent: {
        key
      }
    } = _ref2;
    if (key === 'Backspace') {
      if (idxFocusing >= 0) {
        if (idxFocusing > 0 && !code[idxFocusing]) {
          setIdxFocusing(preValue => preValue - 1);
        }
        const newCode = code.map((item, idx) => idx === idxFocusing ? '' : item);
        setCode(newCode);
      }
      return;
    }
    const keyPressed = key.trim();
    if (idxFocusing <= pinCount - 1 && (0, _constants.keysValid)(keyPressed)) {
      const keyPressedLength = keyPressed.length;
      if (keyPressedLength === 1) {
        const newCode = [...code];
        newCode[idxFocusing] = keyPressed;
        setCode(newCode);
        if (idxFocusing < pinCount - 1) {
          setIdxFocusing(preValue => preValue + 1);
        }
      } else {
        const newCode = [];
        for (let i = 0; i < keyPressedLength; i++) {
          newCode[i] = keyPressed[i];
        }
        setCode(newCode);
        const idxDigitFocusing = keyPressedLength < 1 ? 0 : keyPressedLength >= pinCount ? pinCount - 1 : keyPressedLength;
        setIdxFocusing(() => idxDigitFocusing);
      }
    }
  };

  // Handle submit otp here
  const handleSubmit = (0, _react.useCallback)(() => {
    try {
      const otp = code.join('');
      if (otp.length === pinCount) {
        var _inputRef$current2, _inputRef$current2$cl;
        (_inputRef$current2 = inputRef.current) === null || _inputRef$current2 === void 0 ? void 0 : (_inputRef$current2$cl = _inputRef$current2.clear) === null || _inputRef$current2$cl === void 0 ? void 0 : _inputRef$current2$cl.call(_inputRef$current2);
        setCode((0, _constants.initCode)(pinCount));
        setIdxFocusing(0);
        onSubmit === null || onSubmit === void 0 ? void 0 : onSubmit(otp);
      }
    } catch (error) {}
  }, [code, onSubmit, pinCount]);

  // effect
  (0, _react.useEffect)(() => {
    handleSubmit();
  }, [handleSubmit]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.container
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.boxContainer, boxContainerStyle]
  }, (0, _constants.initCode)(pinCount).map((_, idx) => {
    const digit = code[idx] || _constants.EMPTY_VALUE;
    const isValueFocused = idxFocusing === idx;
    return /*#__PURE__*/_react.default.createElement(_boxDigit.BoxDigit, {
      key: `${idx}`,
      handleOnPress: handleOnPress(idx),
      isValueFocused,
      digit,
      pinCount,
      boxSelectedStyle,
      boxStyle,
      digitStyle
    });
  })), /*#__PURE__*/_react.default.createElement(_reactNative.TextInput, {
    style: styles.inputContainer,
    onKeyPress: handleOnKeyPress,
    maxLength: pinCount,
    ref: inputRef,
    textContentType: _constants.isAutoFillSupported ? 'oneTimeCode' : 'none',
    keyboardType: "numeric",
    autoFocus: true
  }));
};
exports.OTPInput = OTPInput;
const styles = _reactNative.StyleSheet.create({
  container: {
    width: '100%',
    height: 72
  },
  inputContainer: {
    width: 0,
    height: '100%',
    zIndex: -1,
    opacity: 1,
    ..._reactNative.StyleSheet.absoluteFillObject
  },
  boxContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    paddingHorizontal: 20
  }
});
//# sourceMappingURL=index.js.map